@@ -408,6 +408,7 @@ def _save_history(hdulist, tree):
 
 
 def to_fits(tree, schema):
+    """Create hdulist and modified ASDF tree"""
     hdulist = fits.HDUList()
     hdulist.append(fits.PrimaryHDU())
 
@@ -419,8 +420,7 @@ def to_fits(tree, schema):
     # Store the FITS hash in the tree
     tree[FITS_HASH_KEY] = fits_hash(hdulist)
 
-    asdf = fits_embed.AsdfInFits(hdulist, tree)
-    return asdf
+    return hdulist, tree
 
 
 ##############################################################################
@@ -539,20 +539,21 @@ def _load_extra_fits(hdulist, known_keywords, known_datas, tree):
 
     # Add header keywords and data not in schema to extra_fits
     for hdu in hdulist:
-        known = known_keywords.get(hdu, set())
+        # Don't add ASDF hdus to extra_fits for any reason
+        if hdu.name != "ASDF":
+            known = known_keywords.get(hdu, set())
 
-        cards = []
-        for key, val, comment in hdu.header.cards:
-            if not (is_builtin_fits_keyword(key) or
-                    key in known):
-                cards.append([key, val, comment])
+            cards = []
+            for key, val, comment in hdu.header.cards:
+                if not (is_builtin_fits_keyword(key) or
+                        key in known):
+                    cards.append([key, val, comment])
 
-        if len(cards):
-            properties.put_value(
-                ['extra_fits', hdu.name, 'header'], cards, tree)
+            if len(cards):
+                properties.put_value(
+                    ['extra_fits', hdu.name, 'header'], cards, tree)
 
-        if hdu not in known_datas:
-            if hdu.name.lower() != 'asdf':
+            if hdu not in known_datas:
                 if hdu.data is not None:
                     properties.put_value(
                         ['extra_fits', hdu.name, 'data'], hdu.data, tree)
